@@ -1,7 +1,7 @@
 /* about.c - 2000/05/05 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2000-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,13 +22,15 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <stdio.h>
+#include <string.h>
 #include <id3.h>
+#include <errno.h>
 
 #include "about.h"
 #include "easytag.h"
 #include "misc.h"
 #include "msgbox.h"
-#include "mylocale.h"
+#include "i18n.h"
 
 #ifndef PACKAGE_DATA_DIR
 #    include "../pixmaps/EasyTAG_logo.xpm"
@@ -46,6 +48,7 @@ static GtkWidget *AboutWindow = NULL;
  **************/
 void About_Window_Key_Press (GtkWidget *window, GdkEvent *event);
 void Quit_About_Window (void);
+void About_Window_Go_To_Home_Page (void);
 
 
 
@@ -55,7 +58,7 @@ void Quit_About_Window (void);
 /*
  * Close the window when the 'escape' key is pressed.
  */
-void About_Window_Key_Press (GtkWidget *window, GdkEvent *event)
+void About_Window_Key_Press (GtkWidget *window ATTRIBUTE_UNUSED, GdkEvent *event)
 {
     GdkEventKey *kevent;
 
@@ -82,27 +85,30 @@ void Quit_About_Window (void)
     }
 }
 
-
 void Show_About_Window (void)
 {
     GtkWidget *AboutNoteBook;
     GtkWidget *Label;
     GtkWidget *Frame;
-    GtkWidget *VBox;
+    GtkWidget *VBox, *hbox;
     GtkWidget *ScrollWindow;
     GtkWidget *Text;
     GtkWidget *Button;
     GtkWidget *Logo;
     GdkPixmap *pixmap;
     GdkBitmap *mask;
+    GdkFont   *font;
     gchar temp[MAX_STRING_LEN];
+    FILE *file;
     gint i;
     gchar *description_text = 
             _(""
-            "    EasyTAG is an utility for viewing, editing and writing tags of "
-            "your MP3, MP2, FLAC and OGG files. Its simple and nice GTK+ interface "
-            "makes tagging easier."
+            "    EasyTAG is an utility for viewing and editing tags for MP3, MP2, "
+            "FLAC, Ogg Vorbis, MusePack and Monkey's Audio files. Its simple and "
+            "nice GTK+ interface makes tagging easier under GNU/Linux."
             "");
+
+    
     /* Translation contributions */
     gchar *translations_thanks_text [][2]= {
             {"    - Bastian Kleineidam ",      _("(German translation)\n")},
@@ -115,11 +121,16 @@ void Show_About_Window (void)
             {"    - Bjrn Olievier ",          _("(Dutch translation)\n")},
             {"    - Patrik Israelsson ",       _("(Swedish translation)\n")},
             {"    - Szel Miklos ",             _("(Hungarian translation)\n")},
+            {"    - Nagy Boldizsar ",          _("(Hungarian translation)\n")},
             {"    - Cappelletti Lorenzo ",     _("(Italian translation)\n")},
+            {"    - Kostantino ",              _("(Italian translation)\n")},
             {"    - Takeshi Aihana ",          _("(Japanese translation)\n")},
             {"    - Olexander Kunytsa ",       _("(Ukrainian translation)\n")},
+            {"    - Cawko Xakep ",             _("(Ukrainian translation)\n")},
             {"    - Milan Siebenburger ",      _("(Czech translation)\n")},
             {"    - Jaime Serrano Cartagena ", _("(Spanish translation)\n")},
+            {"    - Maciej Kasprzyk ",         _("(Polish translation)\n")},
+            {"    - Pauliuc George ",          _("(Romanian translation)\n")},
             {NULL,NULL}
             };
     /* General contributions */
@@ -144,6 +155,12 @@ void Show_About_Window (void)
             "    - Colin Marquardt\n"
             "    - Goetz Waschk\n"
             "    - Holger Schemel\n"
+            "    - Artur Polaczynski\n"
+            "    - Maciej Kasprzyk\n"
+            "    - Daniel Pichler\n"
+            "    - Philipp Thomas\n"
+            "    - Tony Mancill\n"
+            "    - Pavel Minayev\n"
             "";
 
 
@@ -215,7 +232,12 @@ void Show_About_Window (void)
     gtk_box_pack_start_defaults(GTK_BOX(VBox),Label);
 
 #ifndef ENABLE_OGG
-    Label = gtk_label_new(_("(OGG file support disabled)"));
+    Label = gtk_label_new(_("(Ogg Vorbis file support disabled)"));
+    gtk_box_pack_start_defaults(GTK_BOX(VBox),Label);
+#endif
+
+#ifndef ENABLE_FLAC
+    Label = gtk_label_new(_("(FLAC file support disabled)"));
     gtk_box_pack_start_defaults(GTK_BOX(VBox),Label);
 #endif
 
@@ -231,10 +253,19 @@ void Show_About_Window (void)
     Label = gtk_label_new(temp);
     gtk_box_pack_start_defaults(GTK_BOX(VBox),Label);
 
-    sprintf(temp,_("Web Page: %s"),WEBPAGE"\n");
-    Label = gtk_label_new(temp);
-    gtk_box_pack_start_defaults(GTK_BOX(VBox),Label);
+    hbox = gtk_hbox_new(FALSE,0);
+    gtk_box_pack_start_defaults(GTK_BOX(VBox),hbox);
+    Label = gtk_label_new(_("Web Page: "));
+    gtk_misc_set_alignment(GTK_MISC(Label),1,0.5);
+    gtk_box_pack_start_defaults(GTK_BOX(hbox),Label);
+    Button = gtk_button_new_with_label(WEBPAGE);
+    gtk_box_pack_start_defaults(GTK_BOX(hbox),Button);
+    gtk_signal_connect(GTK_OBJECT(Button),"clicked",(GtkSignalFunc)About_Window_Go_To_Home_Page,NULL);
+    gtk_button_set_relief(GTK_BUTTON(Button),GTK_RELIEF_NONE);
 
+    /* Insert a blank line */
+    Label = gtk_label_new("");
+    gtk_box_pack_start_defaults(GTK_BOX(VBox),Label);
 
     Frame = gtk_frame_new(_("Description:"));
     gtk_frame_set_shadow_type(GTK_FRAME(Frame),GTK_SHADOW_IN);
@@ -276,6 +307,50 @@ void Show_About_Window (void)
     gtk_text_insert(GTK_TEXT(Text),NULL,NULL,NULL,general_thanks_text,-1);
 
 
+    /*
+     * Tab for ChangeLog
+     */
+
+#ifdef PACKAGE_DATA_DIR
+    Label = gtk_label_new(_("Changes"));
+    Frame = gtk_frame_new(NULL);
+    gtk_notebook_append_page (GTK_NOTEBOOK(AboutNoteBook),Frame,Label);
+
+    ScrollWindow = gtk_scrolled_window_new(NULL,NULL);
+    gtk_container_add(GTK_CONTAINER(Frame),ScrollWindow);
+    gtk_container_set_border_width(GTK_CONTAINER(Frame),2);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(ScrollWindow),
+                                   GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
+
+    Text = gtk_text_new(NULL,NULL);
+    gtk_container_add(GTK_CONTAINER(ScrollWindow),Text);
+    gtk_text_set_editable(GTK_TEXT(Text),FALSE);
+    gtk_text_set_word_wrap(GTK_TEXT(Text),TRUE);
+    font = gdk_fontset_load("-*-fixed-medium-r-semicondensed-*-*-120-*-*-*-*-*-*");
+
+
+    // The file 'ChangeLog' to read
+    if ( (file=fopen(PACKAGE_DATA_DIR"/ChangeLog","r"))==0 )
+    {
+        gchar *msg = g_strdup_printf(_("Can't open file '%s' (%s)\n"),PACKAGE_DATA_DIR"/ChangeLog",g_strerror(errno));
+        gtk_text_insert(GTK_TEXT(Text),NULL,NULL,NULL,msg,-1);
+        g_free(msg);
+    }else
+    {
+        while(fgets(temp,sizeof(temp),file))
+        {
+            if (temp[strlen(temp)-1]=='\n')
+                temp[strlen(temp)-1]='\0';
+            if (temp[strlen(temp)-1]=='\r')
+                temp[strlen(temp)-1]='\0';
+            gtk_text_insert(GTK_TEXT(Text),font,NULL,NULL,temp,-1);
+            gtk_text_insert(GTK_TEXT(Text),NULL,NULL,NULL,"\n",-1);
+        }
+        fclose(file);
+    }
+#endif
+
+
     /* 
      * Close Button
      */
@@ -291,3 +366,9 @@ void Show_About_Window (void)
 
     gtk_widget_show_all(AboutWindow);
 }
+
+
+void About_Window_Go_To_Home_Page (void)
+{
+    system("gnome-moz-remote "WEBPAGE);
+}
