@@ -1,7 +1,7 @@
 /* bar.h - 2000/05/05 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2000-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,12 +44,10 @@ GtkWidget *TBRemoveButton;
 GtkWidget *TBUndoButton;
 GtkWidget *TBRedoButton;
 GtkWidget *TBSaveButton;
-GtkWidget *TBScanAllButton;
-GtkWidget *TBRemoveAllButton;
-GtkWidget *TBUndoAllButton;
-GtkWidget *TBRedoAllButton;
-GtkWidget *TBSaveAllButton;
 GtkWidget *TBStopButton;
+GtkWidget *TBShowBrowserButton;
+GtkWidget *TBSelectAllButton;
+GtkWidget *TBInvertSelectionButton;
 GtkWidget *TBQuitButton;
 
 
@@ -67,12 +65,13 @@ enum Action_Menu
     AM_REMOVE,
     AM_UNDO,
     AM_REDO,
+    AM_UNDO_HISTORY,
+    AM_REDO_HISTORY,
     AM_SAVE,
-    AM_SCAN_ALL,
-    AM_REMOVE_ALL,
-    AM_UNDO_ALL,
-    AM_REDO_ALL,
-    AM_SAVE_ALL,
+    AM_SELECT_ALL_FILES,
+    AM_UNSELECT_ALL_FILES,
+    AM_INVERT_SELECTION,
+    AM_DELETE_FILE,
     AM_LOAD_HOME_DIR,
     AM_LOAD_DEFAULT_DIR,
     AM_SET_PATH_AS_DEFAULT,
@@ -81,13 +80,16 @@ enum Action_Menu
     AM_COLLAPSE_TREE,
     AM_INITIALIZE_TREE,
     AM_RELOAD_DIRECTORY,
+    AM_TREE_OR_ARTISTALBUM_VIEW,
     AM_BROWSE_DIRECTORY_WITH,
+    AM_BROWSE_FILE_WITH,
     AM_OPEN_OPTIONS_WINDOW,
     AM_SAVE_CONFIG,
     AM_SCANNER_FILL_TAG,
     AM_SCANNER_RENAME_FILE,
     AM_SCANNER_PROCESS_FIELDS,
     AM_SEARCH_FILE,
+    AM_CDDB_SEARCH,
     AM_FILENAME_FROM_TXT,
     AM_WRITE_PLAYLIST,
     AM_RUN_AUDIO_PLAYER,
@@ -110,7 +112,17 @@ enum Action_Menu
     AM_SORT_ASCENDING_GENRE,
     AM_SORT_DESCENDING_GENRE,
     AM_SORT_ASCENDING_COMMENT,
-    AM_SORT_DESCENDING_COMMENT
+    AM_SORT_DESCENDING_COMMENT,
+    AM_SORT_ASCENDING_FILE_TYPE,
+    AM_SORT_DESCENDING_FILE_TYPE,
+    AM_SORT_ASCENDING_FILE_SIZE,
+    AM_SORT_DESCENDING_FILE_SIZE,
+    AM_SORT_ASCENDING_FILE_DURATION,
+    AM_SORT_DESCENDING_FILE_DURATION,
+    AM_SORT_ASCENDING_FILE_BITRATE,
+    AM_SORT_DESCENDING_FILE_BITRATE,
+    AM_SORT_ASCENDING_FILE_SAMPLERATE,
+    AM_SORT_DESCENDING_FILE_SAMPLERATE
 };
 
 
@@ -129,4 +141,3 @@ void Check_Menu_Item_Update_Browse_Subdir (void);
 
 
 #endif /* __BAR_H__ */
-
