@@ -36,7 +36,7 @@
 
 #include "charset.h"
 #include "setting.h"
-#include "mylocale.h"
+#include "i18n.h"
 
 
 
@@ -128,7 +128,7 @@ const CharsetInfo charset_trans_array[] = {
     {N_("Vietnamese (TCVN)"),                 "x-viet-tcvn5712"      },
     {N_("Vietnamese (VPS)"),                  "x-viet-vps"           },
     {N_("Western (MacRoman)"),                "x-mac-roman"          },
-    // charsets whithout posibly translatable names
+    // charsets whithout possibly translatable names
     {"T61.8bit",                              "T61.8bit"             },
     {"x-imap4-modified-utf7",                 "x-imap4-modified-utf7"},
     {"x-u-escaped",                           "x-u-escaped"          },
@@ -186,7 +186,7 @@ static char* convert_string (const char *string, char *from, char *to)
     outptr = out;
 
  retry:
-    if (iconv(cd, (char **)&input, &length, &outptr, &outleft) == -1)
+    if (iconv(cd, (char **)&input, &length, &outptr, &outleft) == (size_t)(-1))
     {
         int used;
         switch (errno)
@@ -226,8 +226,9 @@ static char* convert_string (const char *string, char *from, char *to)
 #endif
 
 
+
 /*
- * Conversion with UTF-8 for ogg tags
+ * Conversion with UTF-8 for Ogg Vorbis and FLAC tags (current_charset <===> UTF-8)
  */
 char* convert_to_utf8 (const char *string)
 {
@@ -244,17 +245,48 @@ char* convert_from_utf8 (const char *string)
 }
 
 
-/*
- * Commons conversion functions
- */
-char* convert_from_file_to_user (const char *string)
-{
-    char *file_charset = FILE_CHARACTER_SET;
-    char *user_charset = USER_CHARACTER_SET;
 
-    return convert_string(string,file_charset,user_charset);
+/*
+ * Conversion with ISO-8859-1 for ID3v2.3 tags (current_charset <===> ISO-8859-1)
+ */
+char* convert_to_iso88591 (const char *string)
+{
+    char *charset = get_current_charset();
+
+    return convert_string(string, charset, "ISO-8859-1");
 }
 
+char* convert_from_iso88591 (const char *string)
+{
+    char *charset = get_current_charset();
+
+    return convert_string(string, "ISO-8859-1", charset);
+}
+
+
+
+/*
+ * Conversion with "this_charset" for ID3v2.3 tags (current_charset <===> this_charset)
+ */
+char* convert_to_this_charset (const char *string, char *this_charset)
+{
+    char *charset = get_current_charset();
+
+    return convert_string(string, charset, this_charset);
+}
+
+char* convert_from_this_charset (const char *string, char *this_charset)
+{
+    char *charset = get_current_charset();
+
+    return convert_string(string, this_charset, charset);
+}
+
+
+
+/*
+ * Conversion functions using default parameters set by user in the preference window. (USER_CHARACTER_SET <===> FILE_CHARACTER_SET)
+ */
 char* convert_from_user_to_file (const char *string)
 {
     char *file_charset = FILE_CHARACTER_SET;
@@ -263,11 +295,20 @@ char* convert_from_user_to_file (const char *string)
     return convert_string(string,user_charset,file_charset);
 }
 
+char* convert_from_file_to_user (const char *string)
+{
+    char *file_charset = FILE_CHARACTER_SET;
+    char *user_charset = USER_CHARACTER_SET;
+
+    return convert_string(string,file_charset,user_charset);
+}
+
+
 
 GList *Charset_Create_List (void)
 {
     GList *list = NULL;
-    gint i;
+    guint i;
 
     for (i=0; i<CHARSET_TRANS_ARRAY_LEN; i++)
         list = g_list_append(list,_(charset_trans_array[i].charset_title));
@@ -280,7 +321,7 @@ GList *Charset_Create_List (void)
  */
 gchar *Charset_Get_Name_From_Title (gchar *charset_title)
 {
-    gint i;
+    guint i;
 
     if (charset_title)
         for (i=0; i<CHARSET_TRANS_ARRAY_LEN; i++)
@@ -295,7 +336,7 @@ gchar *Charset_Get_Name_From_Title (gchar *charset_title)
  */
 gchar *Charset_Get_Title_From_Name (gchar *charset_name)
 {
-    gint i;
+    guint i;
 
     if (charset_name)
         for (i=0; i<CHARSET_TRANS_ARRAY_LEN; i++)
