@@ -1,7 +1,7 @@
 /* charset.h - 2001/12/04 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2000-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,12 +43,20 @@ extern const CharsetInfo charset_trans_array[];
 
 //static gchar* get_current_charset (void);
 
-/* Used for ogg tags */
+/* Used for Ogg Vorbis and FLAC tags */
 gchar* convert_to_utf8   (const gchar *string);
 gchar* convert_from_utf8 (const gchar *string);
 
-gchar* convert_from_file_to_user (const gchar *string);
+/* Used by default for ID3v2.3 tags (with id3lib) */
+gchar* convert_to_iso88591   (const gchar *string);
+gchar* convert_from_iso88591 (const gchar *string);
+
+gchar* convert_to_this_charset   (const gchar *string, gchar *this_charset);
+gchar* convert_from_this_charset (const gchar *string, gchar *this_charset);
+
+/* May be used for ID3 tags */
 gchar* convert_from_user_to_file (const gchar *string);
+gchar* convert_from_file_to_user (const gchar *string);
 
 GList *Charset_Create_List (void);
 gchar *Charset_Get_Name_From_Title (gchar *charset_title);
@@ -58,4 +66,3 @@ gboolean test_conversion_charset (char *from, char *to);
 
 
 #endif /* __CHARSET_H__ */
-
