@@ -1,7 +1,7 @@
 /* misc.h - 2000/06/28 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2000-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,11 +29,22 @@
  ***************/
 
 GtkWidget *WritePlaylistWindow;
+GtkWidget *playlist_use_mask_name;
 GtkWidget *PlayListNameEntry;
-GtkWidget *playlist_use_name;
 GtkWidget *playlist_use_dir_name;
+GtkWidget *playlist_only_selected_files;
 GtkWidget *playlist_full_path;
 GtkWidget *playlist_relative_path;
+GtkWidget *playlist_create_in_parent_dir;
+GtkWidget *playlist_use_dos_separator;
+GtkWidget *playlist_content_none;
+GtkWidget *playlist_content_filename;
+GtkWidget *playlist_content_mask;
+GtkWidget *PlayListContentMaskEntry;
+
+GtkWidget *LoadFilenameWindow;
+GtkWidget *LoadFileRunScanner;
+
 
 
 /**************
@@ -43,8 +54,8 @@ GtkWidget *playlist_relative_path;
 /*
  * Create Pixmaps, buttons,...
  */
-GtkWidget *Create_Button_With_Pixmap (guint button_type);
-GtkWidget *Create_Pixmap_Icon (gchar **pixmap_name);
+GtkWidget *Create_Button_With_Pixmap         (guint button_type);
+GtkWidget *Create_Pixmap_Icon                (gchar **pixmap_name);
 GtkWidget *Create_Pixmap_Icon_With_Event_Box (gchar **pixmap_name);
 GtkWidget *Create_Button_With_Icon_And_Label (gchar **pixmap_name, gchar *label);
 
@@ -53,7 +64,7 @@ GtkWidget *Create_Button_With_Icon_And_Label (gchar **pixmap_name, gchar *label)
  * Combobox history
  */
 void   Add_To_Combo_Box_History (GtkObject *combobox);
-GList *Add_String_To_Glist (GList *list, gchar *string);
+GList *Add_String_To_Glist      (GList *list, gchar *string);
 
 
 /*
@@ -66,6 +77,7 @@ void Parse_Date (void);
 void Load_Genres_List_To_UI (void);
 void Load_Track_List_To_UI  (void);
 void Init_Character_Translation_Table (void);
+void Focus_Select_Text_In_Editable (GtkWidget *widget);
 
 // Mouse cursor
 void Init_Mouse_Cursor    (void);
@@ -77,11 +89,15 @@ void Set_Unbusy_Cursor    (void);
 GtkTooltips *gtk_tooltips_new_1 (void);
 void Set_Tips_Color (GtkTooltips *tips);
 
-// Run file audio player
-void Run_Audio_Player_With_File_List (void);
-void Run_Audio_Player_With_One_File (void);
+// Run Audio Player
+void Run_Audio_Player_Using_File_List (GList *etfilelist);
+void Run_Audio_Player_Using_Directory (void);
+void Run_Audio_Player_Using_Selection (void);
+void Run_Audio_Player_Using_Browser_Artist_List (void);
+void Run_Audio_Player_Using_Browser_Album_List  (void);
 
 gchar *Convert_Size     (gfloat size);
+gchar *Convert_Size_1   (gfloat size);
 gchar *Convert_Duration (gulong duration);
 
 gulong Get_File_Size (gchar *filename);
