@@ -1,7 +1,7 @@
 /* msgbox.h - 2000/10/13 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2000-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -63,16 +63,17 @@ struct _MsgBoxClass
 
 enum Button_Type 
 {     
-    BUTTON_OK       = 1<<0,
-    BUTTON_YES      = 1<<1,
-    BUTTON_NO       = 1<<2,
-    BUTTON_APPLY    = 1<<3,
-    BUTTON_SAVE     = 1<<4,
-    BUTTON_CANCEL   = 1<<5,
-    BUTTON_CLOSE    = 1<<6,
-    BUTTON_WRITE    = 1<<7,
-    BUTTON_EXECUTE  = 1<<8,
-    BUTTON_SEARCH   = 1<<9
+    BUTTON_OK       = 1<<0 ,
+    BUTTON_YES      = 1<<1 ,
+    BUTTON_NO       = 1<<2 ,
+    BUTTON_APPLY    = 1<<3 ,
+    BUTTON_SAVE     = 1<<4 ,
+    BUTTON_CANCEL   = 1<<5 ,
+    BUTTON_CLOSE    = 1<<6 ,
+    BUTTON_WRITE    = 1<<7 ,
+    BUTTON_EXECUTE  = 1<<8 ,
+    BUTTON_SEARCH   = 1<<9 ,
+    BUTTON_BROWSE   = 1<<10
 };
 
 enum Message_Type 
