@@ -1,7 +1,7 @@
 /* ogg_tag.c - 2001/11/08 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2001-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2001-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 #include "misc.h"
 #include "setting.h"
 #include "charset.h"
-#include "mylocale.h"
+#include "i18n.h"
 
 
 /***************
@@ -47,7 +47,7 @@
 
 #define MULTIFIELD_SEPARATOR " - "
 
-/* OGG fields names :
+/* Ogg Vorbis fields names :
  *  - TITLE        : Track name
  *  - VERSION      : The version field may be used to differentiate multiple version of the same track title in a single collection. (e.g. remix info)
  *  - ALBUM        : The collection name to which this track belongs
@@ -80,18 +80,18 @@ gboolean Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *st
  *************/
 
 /*
- * Read tag data into an ogg file.
+ * Read tag data into an Ogg Vorbis file.
  * Note:
  *  - if field is found but contains no info (strlen(str)==0), we don't read it
  */
 gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
 {
-    FILE *file;
-    vcedit_state *state;
+    FILE           *file;
+    vcedit_state   *state;
     vorbis_comment *vc;
-    gchar *string = NULL;
-    gchar *string1 = NULL;
-    guint field_num;
+    gchar          *string = NULL;
+    gchar          *string1 = NULL;
+    guint           field_num, i;
 
 
     if (!filename || !FileTag)
@@ -105,6 +105,39 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         return FALSE;
     }
 
+    {
+    // Skip the id3v2 tag
+    guchar tmp_id3[4];
+    gulong id3v2size;
+    
+    // Check if there is an ID3v2 tag...
+    fseek(file, 0L, SEEK_SET);
+    if (fread(tmp_id3, 1, 4, file) == 4)
+    {
+        // Calculate ID3v2 length
+        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
+        {
+            // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
+            fseek(file, 2, SEEK_CUR); // Size is 6-9 position
+            if (fread(tmp_id3, 1, 4, file) == 4)
+            {
+                id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
+                                   | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
+                fseek(file, id3v2size, SEEK_SET);
+                g_print(_("Warning : The Ogg Vorbis file '%s' contains an ID3v2 tag.\n"),filename);
+            }else
+            {
+                fseek(file, 0L, SEEK_SET);
+            }
+        }else
+        {
+            fseek(file, 0L, SEEK_SET);
+        }
+    }else
+    {
+        fseek(file, 0L, SEEK_SET);
+    }
+    }
     state = vcedit_new_state();    // Allocate memory for 'state'
     if ( vcedit_open(state,file) < 0 )
     {
@@ -116,13 +149,13 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
 
     /* Get data from tag */
     vc = vcedit_comments(state);
-    //{gint i; for (i=0;i<vc->comments;i++) g_print("%s -> ogg vc< '%s'\n",g_basename(filename),vc->user_comments[i]);}
+    //{gint i; for (i=0;i<vc->comments;i++) g_print("%s -> Ogg vc:'%s'\n",g_basename(filename),vc->user_comments[i]);}
 
     /*********
      * Title *
      *********/
     field_num = 0;
-    while ( (string = vorbis_comment_query(vc,"title",field_num++)) != NULL )
+    while ( (string = vorbis_comment_query(vc,"TITLE",field_num++)) != NULL )
     {
         if ( strlen(string)>0 )
         {
@@ -132,15 +165,16 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->title = g_strdup(string);
             else
                 FileTag->title = g_strconcat(FileTag->title,MULTIFIELD_SEPARATOR,string,NULL);
+            // If strlen = 0, then no allocated data!
+            g_free(string);
         }
-        if (string) g_free(string);
     }
 
     /**********
      * Artist *
      **********/
     field_num = 0;
-    while ( (string = vorbis_comment_query(vc,"artist",field_num++)) != NULL )
+    while ( (string = vorbis_comment_query(vc,"ARTIST",field_num++)) != NULL )
     {
         if ( strlen(string)>0 )
         {
@@ -150,15 +184,15 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->artist = g_strdup(string);
             else
                 FileTag->artist = g_strconcat(FileTag->artist,MULTIFIELD_SEPARATOR,string,NULL);
+            g_free(string);
         }
-        if (string) g_free(string);
     }
 
     /*********
      * Album *
      *********/
     field_num = 0;
-    while ( (string = vorbis_comment_query(vc,"album",field_num++)) != NULL )
+    while ( (string = vorbis_comment_query(vc,"ALBUM",field_num++)) != NULL )
     {
         if ( strlen(string)>0 )
         {
@@ -168,14 +202,14 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->album = g_strdup(string);
             else
                 FileTag->album = g_strconcat(FileTag->album,MULTIFIELD_SEPARATOR,string,NULL);
+            g_free(string);
         }
-        if (string) g_free(string);
     }
 
     /********
      * Year *
      ********/
-    if ( (string = vorbis_comment_query(vc,"date",0)) != NULL && strlen(string)>0 )
+    if ( (string = vorbis_comment_query(vc,"DATE",0)) != NULL && strlen(string)>0 )
     {
         string = convert_from_utf8(string);
         //Strip_String(string);
@@ -186,7 +220,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     /*************************
      * Track and Total Track *
      *************************/
-    if ( (string = vorbis_comment_query(vc,"tracknumber",0)) != NULL && strlen(string)>0 )
+    if ( (string = vorbis_comment_query(vc,"TRACKNUMBER",0)) != NULL && strlen(string)>0 )
     {
         string = convert_from_utf8(string);
         //Strip_String(string);
@@ -195,10 +229,10 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         {
             if (string1)
             {
-                FileTag->track_total = g_strdup_printf("%.2d",atoi(string1+1));
+                FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string1+1));
                 *string1 = '\0';
             }
-            FileTag->track = g_strdup_printf("%.2d",atoi(string));
+            FileTag->track = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string));
         }else
         {
             if (string1)
@@ -215,7 +249,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      * Genre *
      *********/
     field_num = 0;
-    while ( (string = vorbis_comment_query(vc,"genre",field_num++)) != NULL )
+    while ( (string = vorbis_comment_query(vc,"GENRE",field_num++)) != NULL )
     {
         if ( strlen(string)>0 )
         {
@@ -225,8 +259,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->genre = g_strdup(string);
             else
                 FileTag->genre = g_strconcat(FileTag->genre,MULTIFIELD_SEPARATOR,string,NULL);
+            g_free(string);
         }
-        if (string) g_free(string);
     }
 
     /***********
@@ -234,7 +268,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      ***********/
     field_num = 0;
     string1 = NULL; // Cause it may be not updated into the 'while' condition
-    while ( ((string  = vorbis_comment_query(vc,"comment",field_num)) != NULL )   // Winamp format
+    while ( ((string  = vorbis_comment_query(vc,"COMMENT",field_num)) != NULL )   // Winamp format
          || ((string1 = vorbis_comment_query(vc,"",       field_num)) != NULL ) ) // Xmms format
     {
         if ( string && strlen(string)>0 ) // Contains comment to Winamp format and we prefer this format (field name defined)
@@ -245,6 +279,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->comment = g_strdup(string);
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string,NULL);
+            g_free(string);
+            if (string1 && strlen(string1)>0) g_free(string1);
         }else if ( string1 && strlen(string1)>0 ) // Contains comment to Xmms format only
         {
             string1 = convert_from_utf8(string1);
@@ -253,13 +289,30 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->comment = g_strdup(string1);
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string1,NULL);
+            g_free(string1);
         }
-        if (string)  g_free(string);
-        if (string1) g_free(string1);
         string1 = NULL;
         field_num++;
     }
 
+    /***************************
+     * Save unsupported fields *
+     ***************************/
+    for (i=0;i<(guint)vc->comments;i++)
+    {
+        if ( strncasecmp(vc->user_comments[i],"TITLE=",       6) != 0
+          && strncasecmp(vc->user_comments[i],"ARTIST=",      7) != 0
+          && strncasecmp(vc->user_comments[i],"ALBUM=",       6) != 0
+          && strncasecmp(vc->user_comments[i],"DATE=",        5) != 0
+          && strncasecmp(vc->user_comments[i],"TRACKNUMBER=",12) != 0
+          && strncasecmp(vc->user_comments[i],"GENRE=",       6) != 0
+          && strncasecmp(vc->user_comments[i],"COMMENT=",     8) != 0
+          && strncasecmp(vc->user_comments[i],"=",            1) != 0 )
+        {
+            FileTag->other = g_list_append(FileTag->other,g_strdup(vc->user_comments[i]));
+        }
+    }
+
 
     vcedit_clear(state);
     fclose(file);
@@ -271,12 +324,13 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
 
 gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
 {
-    File_Tag *FileTag;
-    gchar *filename_in;
-    FILE *file_in;
-    vcedit_state *state;
+    File_Tag       *FileTag;
+    gchar          *filename_in;
+    FILE           *file_in;
+    vcedit_state   *state;
     vorbis_comment *vc;
-    gchar *string, *string1;
+    gchar          *string, *string1;
+    GList          *list;
 
 
     if (!ETFile || !ETFile->FileTag)
@@ -293,6 +347,39 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         return FALSE;
     }
 
+    {
+    // Skip the id3v2 tag
+    guchar tmp_id3[4];
+    gulong id3v2size;
+    
+    // Check if there is an ID3v2 tag...
+    fseek(file_in, 0L, SEEK_SET);
+    if (fread(tmp_id3, 1, 4, file_in) == 4)
+    {
+        // Calculate ID3v2 length
+        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
+        {
+            // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
+            fseek(file_in, 2, SEEK_CUR); // Size is 6-9 position
+            if (fread(tmp_id3, 1, 4, file_in) == 4)
+            {
+                id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
+                                   | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
+                fseek(file_in, id3v2size, SEEK_SET);
+            }else
+            {
+                fseek(file_in, 0L, SEEK_SET);
+            }
+        }else
+        {
+            fseek(file_in, 0L, SEEK_SET);
+        }
+    }else
+    {
+        fseek(file_in, 0L, SEEK_SET);
+    }
+    }
+
     state = vcedit_new_state();    // Allocate memory for 'state'
     if ( vcedit_open(state,file_in) < 0 )
     {
@@ -312,7 +399,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
      *********/
     if ( FileTag->title )
     {
-        string  = g_strconcat("title=",FileTag->title,NULL);
+        string  = g_strconcat("TITLE=",FileTag->title,NULL);
         string1 = convert_to_utf8(string);
         vorbis_comment_add(vc,string1);
         g_free(string);
@@ -324,7 +411,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
      **********/
     if ( FileTag->artist )
     {
-        string  = g_strconcat("artist=",FileTag->artist,NULL);
+        string  = g_strconcat("ARTIST=",FileTag->artist,NULL);
         string1 = convert_to_utf8(string);
         vorbis_comment_add(vc,string1);
         g_free(string);
@@ -336,7 +423,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
      *********/
     if ( FileTag->album )
     {
-        string  = g_strconcat("album=",FileTag->album,NULL);
+        string  = g_strconcat("ALBUM=",FileTag->album,NULL);
         string1 = convert_to_utf8(string);
         vorbis_comment_add(vc,string1);
         g_free(string);
@@ -348,7 +435,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
      ********/
     if ( FileTag->year )
     {
-        string  = g_strconcat("date=",FileTag->year,NULL);
+        string  = g_strconcat("DATE=",FileTag->year,NULL);
         string1 = convert_to_utf8(string);
         vorbis_comment_add(vc,string1);
         g_free(string);
@@ -361,9 +448,9 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->track )
     {
         if ( FileTag->track_total && strlen(FileTag->track_total)>0 )
-            string = g_strconcat("tracknumber=",FileTag->track,"/",FileTag->track_total,NULL);
+            string = g_strconcat("TRACKNUMBER=",FileTag->track,"/",FileTag->track_total,NULL);
         else
-            string = g_strconcat("tracknumber=",FileTag->track,NULL);
+            string = g_strconcat("TRACKNUMBER=",FileTag->track,NULL);
         string1 = convert_to_utf8(string);
         vorbis_comment_add(vc,string1);
         g_free(string);
@@ -375,7 +462,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
      *********/
     if ( FileTag->genre )
     {
-        string  = g_strconcat("genre=",FileTag->genre,NULL);
+        string  = g_strconcat("GENRE=",FileTag->genre,NULL);
         string1 = convert_to_utf8(string);
         vorbis_comment_add(vc,string1);
         g_free(string);
@@ -389,7 +476,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     if ( FileTag->comment )
     {
         // Format used in winamp plugin
-        string = g_strconcat("comment=",FileTag->comment,NULL);
+        string = g_strconcat("COMMENT=",FileTag->comment,NULL);
         string1 = convert_to_utf8(string);
         vorbis_comment_add(vc,string1);
         g_free(string);
@@ -406,7 +493,17 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         }
     }
 
-    //{gint i; for (i = 0; i < vc->comments; i++) g_print("%s -> ogg vc< '%s'\n",g_basename(filename_in),vc->user_comments[i]);}
+    /**************************
+     * Set unsupported fields *
+     **************************/
+    list = FileTag->other;
+    while (list)
+    {
+        if (list->data)
+            vorbis_comment_add(vc,(gchar *)list->data);
+        list = list->next;
+    }
+
 
     /* Write tag */
     if ( Ogg_Tag_Write_File(file_in,filename_in,state) == FALSE )
@@ -478,123 +575,4 @@ gboolean Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *st
 }
 
 
-
-
-
-/***************
- * Header info *
- ***************/
-
-gboolean Ogg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
-{
-    FILE *file;
-    OggVorbis_File vf;
-    vorbis_info *vi;
-    gint encoder_version = 0;
-    gint channels = 0;
-    glong rate = 0;
-    glong bitrate_upper = 0;
-    glong bitrate_nominal = 0;
-    glong bitrate_lower = 0;
-    gdouble duration = 0;
-    gulong filesize;
-
-
-    if (!filename || !ETFileInfo)
-        return FALSE;
-
-    if ( (file=fopen(filename,"r"))==NULL )
-    {
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename,g_strerror(errno));
-        return FALSE;
-    }
-
-    if (ov_open(file,&vf,NULL,0) == 0)
-    {
-        if ( (vi=ov_info(&vf,0)) != NULL )
-        {
-            encoder_version = vi->version;         // Vorbis encoder version used to create this bitstream.
-            channels        = vi->channels;        // Number of channels in bitstream.
-            rate            = vi->rate;            // (Hz) Sampling rate of the bitstream.
-            bitrate_upper   = vi->bitrate_upper;   // (b/s) Specifies the upper limit in a VBR bitstream.
-            bitrate_nominal = vi->bitrate_nominal; // (b/s) Specifies the average bitrate for a VBR bitstream.
-            //bitrate_nominal = ov_bitrate(&vf,-1);  // (b/s) Specifies the average bitrate for the specified logical bitstream.
-            bitrate_lower   = vi->bitrate_nominal; // (b/s) Specifies the lower limit in a VBR bitstream.
-
-            duration        = ov_time_total(&vf,-1); // (s) Total time.
-        }
-        ov_clear(&vf); // This close also the file
-    }else
-    {
-        fclose(file);
-    }
-
-    filesize = Get_File_Size(filename);
-
-    ETFileInfo->version    = encoder_version;
-    ETFileInfo->bitrate    = bitrate_nominal/1000;
-    ETFileInfo->samplerate = rate;
-    ETFileInfo->mode       = channels;
-    ETFileInfo->size       = filesize;
-    ETFileInfo->duration   = duration;
-
-    ETFileList_TotalSize     += filesize;
-    ETFileList_TotalDuration += duration;
-
-    return TRUE;
-}
-
-
-gboolean Ogg_Header_Display_File_Info_To_UI (gchar *filename, ET_File_Info *ETFileInfo)
-{
-    gchar *text;
-    gchar *time = NULL;
-    gchar *time1 = NULL;
-    gchar *size = NULL;
-    gchar *size1 = NULL;
-
-    /* Encoder version */
-    gtk_label_set_text(GTK_LABEL(VersionLabel),_("Encoder:"));
-    text = g_strdup_printf("%d",ETFileInfo->version);
-    gtk_label_set_text(GTK_LABEL(VersionValueLabel),text);
-    g_free(text);
-
-    /* Bitrate */
-    text = g_strdup_printf(_("%d kb/s"),ETFileInfo->bitrate);
-    gtk_label_set_text(GTK_LABEL(BitrateValueLabel),text);
-    g_free(text);
-
-    /* Samplerate */
-    text = g_strdup_printf(_("%d Hz"),ETFileInfo->samplerate);
-    gtk_label_set_text(GTK_LABEL(SampleRateValueLabel),text);
-    g_free(text);
-
-    /* Mode */
-    gtk_label_set_text(GTK_LABEL(ModeLabel),_("Channels:"));
-    text = g_strdup_printf("%d",ETFileInfo->mode);
-    gtk_label_set_text(GTK_LABEL(ModeValueLabel),text);
-    g_free(text);
-
-    /* Size */
-    size  = Convert_Size(ETFileInfo->size);
-    size1 = Convert_Size(ETFileList_TotalSize);
-    text  = g_strdup_printf("%s (%s)",size,size1);
-    gtk_label_set_text(GTK_LABEL(SizeValueLabel),text);
-    if (size)  g_free(size);
-    if (size1) g_free(size1);
-    g_free(text);
-
-    /* Duration */
-    time  = Convert_Duration(ETFileInfo->duration);
-    time1 = Convert_Duration(ETFileList_TotalDuration);
-    text  = g_strdup_printf("%s (%s)",time,time1);
-    gtk_label_set_text(GTK_LABEL(DurationValueLabel),text);
-    if (time)  g_free(time);
-    if (time1) g_free(time1);
-    g_free(text);
-
-    return TRUE;
-}
-
 #endif /* ENABLE_OGG */
-
