@@ -1,7 +1,7 @@
 /* prefs.h - 2000/05/06 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2000-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,10 +40,12 @@ GtkWidget *BrowserLineStyleOptionMenu;
 GtkWidget *BrowserExpanderStyleOptionMenu;
 GtkWidget *WriteId3v1Tag;
 GtkWidget *WriteId3v2Tag;
+GtkWidget *UseId3v2Padding;
 GtkWidget *StripTagWhenEmptyFields;
 GtkWidget *BrowseSubdir;
 GtkWidget *OpenSelectedBrowserNode;
 GtkWidget *KeepTreeBrowserInMemory;
+GtkWidget *ConvertOldId3v2TagVersion;
 GtkWidget *SaveConfigBeforeExit;
 
 /* User interface */
@@ -57,6 +59,9 @@ GtkWidget *PaneHandleButton1;
 GtkWidget *SetPaneHandlePosition2;
 GtkWidget *PaneHandlePosition2;
 GtkWidget *PaneHandleButton2;
+GtkWidget *SetPaneHandlePosition3;
+GtkWidget *PaneHandlePosition3;
+GtkWidget *PaneHandleButton3;
 
 GtkWidget *ShowHeaderInfos;
 GtkWidget *UseColoredTooltips;
@@ -65,9 +70,11 @@ GtkWidget *UseColoredTooltips;
 GtkWidget *ReplaceIllegalCharactersInFilename;
 GtkWidget *DateAutoCompletion;
 GtkWidget *NumberTrackFormated;
+GtkWidget *NumberTrackFormatedSpinButton;
 GtkWidget *OggTagWriteXmmsComment;
 GtkWidget *SortingFileOptionMenu;
 GtkWidget *SortingFileCaseSensitive;
+GtkWidget *UseISO88591CharacterSetTranslation;
 GtkWidget *UseCharacterSetTranslation;
 GtkWidget *FileCharacterSetEntry;
 GtkWidget *UserCharacterSetEntry;
@@ -79,24 +86,47 @@ GtkWidget *MessageBoxPositionMouse;
 GtkWidget *FilePlayerEntry;
 
 /* Scanner */
-GtkWidget *ConvertUnderscoreAndP20IntoSpace;
-GtkWidget *ConvertSpaceIntoUnderscore;
+GtkWidget *FTSConvertUnderscoreAndP20IntoSpace;
+GtkWidget *FTSConvertSpaceIntoUnderscore;
+GtkWidget *RFSConvertUnderscoreAndP20IntoSpace;
+GtkWidget *RFSConvertSpaceIntoUnderscore;
 GtkWidget *OverwriteTagField;
 GtkWidget *OpenScannerWindowOnStartup;
 GtkWidget *ScannerWindowOnTop;
 
 GtkWidget *SetDefaultComment;
 GtkWidget *DefaultComment;
+GtkWidget *Crc32Comment;
 
 GtkWidget *SetScannerWindowPosition;
 GtkWidget *ScannerWindowX;
 GtkWidget *ScannerWindowY;
 GtkWidget *ScannerWindowButton;
 
+/* CDDB */
+GtkWidget *CddbServerName;
+GtkWidget *CddbServerPort;
+GtkWidget *CddbServerCgiPath;
+GtkWidget *CddbUseProxy;
+GtkWidget *CddbProxyName;
+GtkWidget *CddbProxyPort;
+GtkWidget *CddbProxyUserName;
+GtkWidget *CddbProxyUserPassword;
+
+GtkWidget *SetCddbWindowSize;
+GtkWidget *CddbWindowWidth;
+GtkWidget *CddbWindowHeight;
+GtkWidget *CddbWindowButton;
+GtkWidget *SetCddbPaneHandlePosition;
+GtkWidget *CddbPaneHandlePosition;
+GtkWidget *CddbPaneHandleButton;
+
+
 /* Confirmation */
 GtkWidget *ConfirmBeforeExit;
 GtkWidget *ConfirmWriteTag;
 GtkWidget *ConfirmRenameFile;
+GtkWidget *ConfirmDeleteFile;
 GtkWidget *ConfirmWritePlayList;
 
 
