@@ -1,7 +1,7 @@
 /* config.h - 2000/06/21 */
 /*
- *  EasyTAG - Tag editor for MP3 and OGG files
- *  Copyright (C) 2000-2002  Jerome Couderc <j.couderc@ifrance.com>
+ *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
+ *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -54,7 +54,9 @@ gint     BROWSER_LINE_STYLE;
 gint     BROWSER_EXPANDER_STYLE;
 gint     WRITE_ID3V1_TAG;
 gint     WRITE_ID3V2_TAG;
+gint     USE_ID3V2_PADDING;
 gint     STRIP_TAG_WHEN_EMPTY_FIELDS;
+gint     CONVERT_OLD_ID3V2_TAG_VERSION;
 gint     BROWSE_SUBDIR;
 gint     OPEN_SELECTED_BROWSER_NODE;
 gint     KEEP_TREE_BROWSER_IN_MEMORY;
@@ -68,16 +70,21 @@ gint     SET_PANE_HANDLE_POSITION1;
 gint     PANE_HANDLE_POSITION1;
 gint     SET_PANE_HANDLE_POSITION2;
 gint     PANE_HANDLE_POSITION2;
+gint     SET_PANE_HANDLE_POSITION3;
+gint     PANE_HANDLE_POSITION3;
 gint     SHOW_HEADER_INFO;
 
 gint     USE_COLORED_TOOLTIPS;
 
 /* Scanner */
-gint    CONVERT_UNDERSCORE_AND_P20_INTO_SPACE;
-gint    CONVERT_SPACE_INTO_UNDERSCORE;
+gint    FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE;
+gint    FTS_CONVERT_SPACE_INTO_UNDERSCORE;
+gint    RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE;
+gint    RFS_CONVERT_SPACE_INTO_UNDERSCORE;
 gint    OVERWRITE_TAG_FIELD;
 gint    SET_DEFAULT_COMMENT;
 gchar   *DEFAULT_COMMENT;
+gint    SET_CRC32_COMMENT;
 gint    OPEN_SCANNER_WINDOW_ON_STARTUP;
 gint    SCANNER_WINDOW_ON_TOP;
 gint    SET_SCANNER_WINDOW_POSITION;
@@ -88,9 +95,11 @@ gint    SCANNER_WINDOW_Y;
 gint     REPLACE_ILLEGAL_CHARACTERS_IN_FILENAME;
 gint     DATE_AUTO_COMPLETION;
 gint     NUMBER_TRACK_FORMATED;
+gint     NUMBER_TRACK_FORMATED_SPIN_BUTTON;
 gint     OGG_TAG_WRITE_XMMS_COMMENT;
 gint     SORTING_FILE_MODE;
 gint     SORTING_FILE_CASE_SENSITIVE;
+gint     USE_ISO_8859_1_CHARACTER_SET_TRANSLATION;
 gint     USE_CHARACTER_SET_TRANSLATION;
 gchar   *FILE_CHARACTER_SET;
 gchar   *USER_CHARACTER_SET;
@@ -106,15 +115,18 @@ gint     CONFIRM_BEFORE_EXIT;
 gint     CONFIRM_WRITE_TAG;
 gint     CONFIRM_RENAME_FILE;
 gint     CONFIRM_WRITE_PLAYLIST;
+gint     CONFIRM_DELETE_FILE;
 
 /* Scanner window */
 gint     PROCESS_FILENAME_FIELD;
 gint     PROCESS_TITLE_FIELD;
 gint     PROCESS_ARTIST_FIELD;
 gint     PROCESS_ALBUM_FIELD;
+gint     PROCESS_GENRE_FIELD;
 gint     PROCESS_COMMENT_FIELD;
 gint     PF_CONVERT_INTO_SPACE;
 gint     PF_CONVERT_SPACE;
+gint     PF_CONVERT;
 gint     PF_CONVERT_ALL_UPPERCASE;
 gint     PF_CONVERT_ALL_DOWNCASE;
 gint     PF_CONVERT_FIRST_LETTER_UPPERCASE;
@@ -123,12 +135,72 @@ gint     PF_REMOVE_SPACE;
 gint     PF_INSERT_SPACE;
 gint     PF_ONLY_ONE_SPACE;
 
-/* Playlist */
+/* Playlist window */
 gchar   *PLAYLIST_NAME;
-gint     PLAYLIST_USE_NAME;
+gint     PLAYLIST_USE_MASK_NAME;
 gint     PLAYLIST_USE_DIR_NAME;
+gint     PLAYLIST_ONLY_SELECTED_FILES;
 gint     PLAYLIST_FULL_PATH;
 gint     PLAYLIST_RELATIVE_PATH;
+gint     PLAYLIST_CREATE_IN_PARENT_DIR;
+gint     PLAYLIST_USE_DOS_SEPARATOR;
+gint     PLAYLIST_CONTENT_NONE;
+gint     PLAYLIST_CONTENT_FILENAME;
+gint     PLAYLIST_CONTENT_MASK;
+gchar   *PLAYLIST_CONTENT_MASK_VALUE;
+
+/* "Load filenames from txt" window */
+gint     LOAD_FILE_RUN_SCANNER;
+
+/* CDDB in preferences window */
+gchar   *CDDB_SERVER_NAME;
+gint     CDDB_SERVER_PORT;
+gchar   *CDDB_SERVER_CGI_PATH;
+gint     CDDB_USE_PROXY;
+gchar   *CDDB_PROXY_NAME;
+gint     CDDB_PROXY_PORT;
+gchar   *CDDB_PROXY_USER_NAME;
+gchar   *CDDB_PROXY_USER_PASSWORD;
+
+gint     SET_CDDB_WINDOW_SIZE;
+gint     CDDB_WINDOW_HEIGHT;
+gint     CDDB_WINDOW_WIDTH;
+gint     SET_CDDB_PANE_HANDLE_POSITION;
+gint     CDDB_PANE_HANDLE_POSITION;
+
+/* CDDB window */
+gint     CDDB_SEARCH_IN_ALL_FIELDS;
+gint     CDDB_SEARCH_IN_ARTIST_FIELD;
+gint     CDDB_SEARCH_IN_TITLE_FIELD;
+gint     CDDB_SEARCH_IN_TRACK_NAME_FIELD;
+gint     CDDB_SEARCH_IN_OTHER_FIELD;
+
+gint     CDDB_SHOW_CATEGORIES;
+
+gint     CDDB_SEARCH_IN_ALL_CATEGORIES;
+gint     CDDB_SEARCH_IN_BLUES_CATEGORY;
+gint     CDDB_SEARCH_IN_CLASSICAL_CATEGORY;
+gint     CDDB_SEARCH_IN_COUNTRY_CATEGORY;
+gint     CDDB_SEARCH_IN_FOLK_CATEGORY;
+gint     CDDB_SEARCH_IN_JAZZ_CATEGORY;
+gint     CDDB_SEARCH_IN_MISC_CATEGORY;
+gint     CDDB_SEARCH_IN_NEWAGE_CATEGORY;
+gint     CDDB_SEARCH_IN_REGGAE_CATEGORY;
+gint     CDDB_SEARCH_IN_ROCK_CATEGORY;
+gint     CDDB_SEARCH_IN_SOUNDTRACK_CATEGORY;
+
+gint     CDDB_SET_TO_ALL_FIELDS;
+gint     CDDB_SET_TO_TITLE;
+gint     CDDB_SET_TO_ARTIST;
+gint     CDDB_SET_TO_ALBUM;
+gint     CDDB_SET_TO_YEAR;
+gint     CDDB_SET_TO_TRACK;
+gint     CDDB_SET_TO_TRACK_TOTAL;
+gint     CDDB_SET_TO_GENRE;
+gint     CDDB_SET_TO_FILE_NAME;
+
+gint     CDDB_RUN_SCANNER;
+
 
 /* Other parameters */
 gint     OPTIONS_NOTEBOOK_PAGE;
@@ -148,9 +220,11 @@ void Save_Config_To_File (void);
 void Save_Config_Now (void);
 
 gboolean Create_Easytag_Directory (void);
+void     Setting_Create_Files     (void);
 
-void   Save_Glist_To_File (GList *list, gchar *file);
+void   Save_Glist_To_File     (GList *list, gchar *file);
 GList *Create_Glist_From_File (gchar *file);
+void   Free_Glist             (GList *list);
 
 
 /* MasksList */
@@ -177,9 +251,13 @@ void   Save_Path_Entry_List (GList *list);
 GList *Load_Play_List_Name_List (void);
 void   Save_Play_List_Name_List (GList *list);
 
-/* Run Program combobox */
-GList *Load_Run_Program_List (void);
-void   Save_Run_Program_List (GList *list);
+/* Run Program combobox (tree browser) */
+GList *Load_Run_Program_With_Directory_List (void);
+void   Save_Run_Program_With_Directory_List (GList *list);
+
+/* Run Program combobox (file browser) */
+GList *Load_Run_Program_With_File_List (void);
+void   Save_Run_Program_With_File_List (GList *list);
 
 /* 'FilePlayerEntry' combobox */
 GList *Load_Audio_File_Player_List (void);
@@ -193,5 +271,17 @@ void   Save_Search_File_List (GList *list);
 GList *Load_File_To_Load_List (void);
 void   Save_File_To_Load_List (GList *list);
 
+/* 'PlayListContentMaskEntry' combobox */
+GList *Load_Playlist_Content_Mask_List (void);
+void   Save_Playlist_Content_Mask_List (GList *list);
+
+/* 'CddbSearchStringEntry' combobox */
+GList *Load_Cddb_Search_String_List (void);
+void   Save_Cddb_Search_String_List (GList *list);
+
+/* 'CddbSearchStringInResultEntry' combobox */
+GList *Load_Cddb_Search_String_In_Result_List (void);
+void   Save_Cddb_Search_String_In_Result_List (GList *list);
+
 
 #endif /* __CONFIG_H__ */
